==> nan_common_utils-0.0.27.tar.gz: android/src/main/java/com/example/nan_common_utils/NanMessageChannel.java <==
package com.example.nan_common_utils;

import android.content.Context;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.amap.api.maps.model.LatLng;
//import com.amap.api.maps2d.model.LatLng;
import com.amap.api.services.core.AMapException;
import com.amap.api.services.core.LatLonPoint;
import com.amap.api.services.geocoder.GeocodeResult;
import com.amap.api.services.geocoder.GeocodeSearch;
import com.amap.api.services.geocoder.RegeocodeResult;

import org.jetbrains.annotations.NotNull;

import java.util.HashMap;
import java.util.Map;

import io.flutter.plugin.common.BasicMessageChannel;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.StandardMessageCodec;

public class NanMessageChannel {
    private static BasicMessageChannel<Object> jumpMessageChannel;
    private static Map locationMap;
    private static Context mContext;
    public static GeocodeSearch geocoderSearch;
    private static LatLng latLng;

    public  static void init(Context context,BinaryMessenger binaryMessenger){
        mContext = context;
        jumpMessageChannel = new BasicMessageChannel<Object>(binaryMessenger, "testDidiView2", StandardMessageCodec.INSTANCE);
        jumpMessageChannel.setMessageHandler(new BasicMessageChannel.MessageHandler<Object>() {
            @Override
            public void onMessage(@Nullable @org.jetbrains.annotations.Nullable Object message, @NonNull @NotNull BasicMessageChannel.Reply<Object> reply) {
                Map<Object, Object> arguments = (Map<Object, Object>) message;
                String method = (String) arguments.get("method");
                if (method.equals("haha")){

                    jumpMessageChannel.send(locationMap);
                }
            }
        });
    }

    public static void geocoderSearch(final LifecycleProvider.OnLocationAction locationAction){
        geocoderSearch = new GeocodeSearch(mContext);
        geocoderSearch.setOnGeocodeSearchListener(new GeocodeSearch.OnGeocodeSearchListener() {
            @Override
            public void onRegeocodeSearched(RegeocodeResult result, int i) {
                if (i == AMapException.CODE_AMAP_SUCCESS){
                    if (result != null && result.getRegeocodeAddress() != null
                            && result.getRegeocodeAddress().getFormatAddress() != null) {
//                        tvAddress.setText(result.getRegeocodeAddress().getFormatAddress());
                        String address = result.getRegeocodeAddress().getFormatAddress();
                        LatLonPoint point = result.getRegeocodeQuery().getPoint();
                        latLng = new LatLng(point.getLatitude(), point.getLongitude());

                        NanMessageChannel.returnLocation(latLng,result.getRegeocodeAddress().getFormatAddress());
                        if (null != locationAction){
                            locationAction.onLocation(result.getRegeocodeAddress().getFormatAddress());
                        }
                    }
                }
            }

            @Override
            public void onGeocodeSearched(GeocodeResult geocodeResult, int i) {

            }
        });
    }

    public static void returnLocation(LatLng latLng, String address){
        Map map = new HashMap();
        map.put("longitude",String.valueOf(latLng.longitude));
        map.put("latitude",String.valueOf(latLng.latitude));
        map.put("address",address);
        locationMap = map;
    }
}

==> nan_common_utils-0.0.28.tar.gz: android/src/main/java/com/example/nan_common_utils/NanMessageChannel.java <==
package com.example.nan_common_utils;

import android.content.Context;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.amap.api.maps.model.LatLng;
//import com.amap.api.maps2d.model.LatLng;
import com.amap.api.services.core.AMapException;
import com.amap.api.services.core.LatLonPoint;
import com.amap.api.services.geocoder.GeocodeResult;
import com.amap.api.services.geocoder.GeocodeSearch;
import com.amap.api.services.geocoder.RegeocodeResult;

import org.jetbrains.annotations.NotNull;

import java.util.HashMap;
import java.util.Map;

import io.flutter.plugin.common.BasicMessageChannel;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.StandardMessageCodec;

public class NanMessageChannel {
    private static BasicMessageChannel<Object> jumpMessageChannel;
    private static Map locationMap;
    private static Context mContext;
    public static GeocodeSearch geocoderSearch;
    private static LatLng latLng;

    public  static void init(Context context, BinaryMessenger binaryMessenger, final LifecycleProvider.CurrentPositionAction currentPositionAction){
        mContext = context;
        jumpMessageChannel = new BasicMessageChannel<Object>(binaryMessenger, "testDidiView2", StandardMessageCodec.INSTANCE);
        jumpMessageChannel.setMessageHandler(new BasicMessageChannel.MessageHandler<Object>() {
            @Override
            public void onMessage(@Nullable @org.jetbrains.annotations.Nullable Object message, @NonNull @NotNull BasicMessageChannel.Reply<Object> reply) {
                Map<Object, Object> arguments = (Map<Object, Object>) message;
                String method = (String) arguments.get("method");
                if (method.equals("haha")){
                    jumpMessageChannel.send(locationMap);
                }else if ("currentPosition".equals(method)){
                    if (null != currentPositionAction){
                        currentPositionAction.onLocatin();
                    }
                }
            }
        });
    }

    public static void geocoderSearch(final LifecycleProvider.OnLocationAction locationAction){
        geocoderSearch = new GeocodeSearch(mContext);
        geocoderSearch.setOnGeocodeSearchListener(new GeocodeSearch.OnGeocodeSearchListener() {
            @Override
            public void onRegeocodeSearched(RegeocodeResult result, int i) {
                if (i == AMapException.CODE_AMAP_SUCCESS){
                    if (result != null && result.getRegeocodeAddress() != null
                            && result.getRegeocodeAddress().getFormatAddress() != null) {
//                        tvAddress.setText(result.getRegeocodeAddress().getFormatAddress());
                        String address = result.getRegeocodeAddress().getFormatAddress();
                        LatLonPoint point = result.getRegeocodeQuery().getPoint();
                        latLng = new LatLng(point.getLatitude(), point.getLongitude());

                        NanMessageChannel.returnLocation(latLng,result.getRegeocodeAddress().getFormatAddress());
                        if (null != locationAction){
                            locationAction.onLocation(result.getRegeocodeAddress().getFormatAddress());
                        }
                    }
                }
            }

            @Override
            public void onGeocodeSearched(GeocodeResult geocodeResult, int i) {

            }
        });
    }

    public static void returnLocation(LatLng latLng, String address){
        Map map = new HashMap();
        map.put("longitude",String.valueOf(latLng.longitude));
        map.put("latitude",String.valueOf(latLng.latitude));
        map.put("address",address);
        locationMap = map;
    }
}
